"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const React = tslib_1.__importStar(require("react"));
const react_native_1 = require("react-native");
/**
 * ? Local Imports
 */
const Icon_1 = tslib_1.__importDefault(require("./components/Icon"));
const RNSingleSelect_style_1 = tslib_1.__importStar(require("./RNSingleSelect.style"));
class RNSingleSelect extends React.Component {
    constructor(props) {
        super(props);
        this.iconRef = undefined;
        this.animateBorderRadius = () => {
            react_native_1.Animated.timing(this.state.borderRadius, {
                toValue: this.state.menuToggled ? 16 : 0,
                duration: 1250,
                easing: react_native_1.Easing.bounce,
                useNativeDriver: true,
            }).start();
        };
        this.animateSelectionBar = () => {
            react_native_1.Animated.timing(this.state.menuBarYTranslate, {
                toValue: this.state.menuToggled ? 0 : 100,
                duration: 250,
                easing: react_native_1.Easing.ease,
                useNativeDriver: true,
            }).start();
        };
        this.handleOnToggleMenuBar = () => {
            this.iconRef?.onPressAnimation();
            this.animateBorderRadius();
            this.animateSelectionBar();
            this.setState({ menuToggled: !this.state.menuToggled });
        };
        this.handleOnSelectItem = (item) => {
            this.setState({ selectedItem: item }, () => {
                this.handleOnToggleMenuBar();
            });
        };
        /* -------------------------------------------------------------------------- */
        /*                               Render Methods                               */
        /* -------------------------------------------------------------------------- */
        this.renderSingleSelectButton = () => {
            return (<react_native_1.TouchableOpacity onPress={() => {
                this.handleOnToggleMenuBar();
            }} {...this.props}>
        <react_native_1.Animated.View style={[
                RNSingleSelect_style_1.default.buttonContainer,
                {
                    borderRadius: this.state.borderRadius,
                },
                this.props.buttonContainerStyle,
            ]}>
          <react_native_1.View style={RNSingleSelect_style_1.default.buttonContainerGlue}>
            <react_native_1.Text style={RNSingleSelect_style_1._placeholderTextStyle(this.state.selectedItem)}>
              {this.state.selectedItem
                ? this.state.selectedItem.value
                : this.props.placeholder || "Select"}
            </react_native_1.Text>
            <Icon_1.default ref={(ref) => (this.iconRef = ref)} style={[RNSingleSelect_style_1.default.arrowImageStyle, this.props.arrowImageStyle]} {...this.props}/>
          </react_native_1.View>
        </react_native_1.Animated.View>
      </react_native_1.TouchableOpacity>);
        };
        this.renderMenuItem = (item, index) => {
            const { value } = item;
            return (<react_native_1.TouchableHighlight style={RNSingleSelect_style_1._menuItemContainer(index, this.props.data)} onPress={() => {
                this.handleOnSelectItem(item);
                this.props.onSelect && this.props.onSelect(item);
            }}>
        <react_native_1.Text style={[RNSingleSelect_style_1.default.menuItemTextStyle, this.props.menuItemTextStyle]}>
          {value}
        </react_native_1.Text>
      </react_native_1.TouchableHighlight>);
        };
        this.renderMenuBar = () => {
            const rotate = this.state.menuBarYTranslate.interpolate({
                inputRange: [0, 25, 50, 75, 100],
                outputRange: [0, 0.5, 0.75, 0.9, 1],
            });
            return (<react_native_1.Animated.View style={[
                RNSingleSelect_style_1.default.menuBarContainer,
                {
                    transform: [{ scaleY: rotate }],
                },
                this.props.menuBarContainerStyle,
            ]}>
        <react_native_1.ScrollView>
          {this.props.data &&
                this.props.data.length > 0 &&
                this.props.data.map((item, index) => this.renderMenuItem(item, index))}
        </react_native_1.ScrollView>
      </react_native_1.Animated.View>);
        };
        this.state = {
            selectedItem: null,
            menuToggled: false,
            borderRadius: new react_native_1.Animated.Value(16),
            menuBarYTranslate: new react_native_1.Animated.Value(0),
        };
    }
    render() {
        return (<react_native_1.View>
        {this.renderSingleSelectButton()}
        {this.renderMenuBar()}
      </react_native_1.View>);
    }
}
exports.default = RNSingleSelect;
//# sourceMappingURL=RNSingleSelect.js.map